Author: tfmorris
Date: 2008-04-18 20:34:35-0700
New Revision: 14383
Modified:
trunk/src/model/src/org/argouml/model/CollaborationsHelper.java
trunk/src/model/src/org/argouml/model/ModelManagementHelper.java
Log:
Javadoc cleanups
Modified: trunk/src/model/src/org/argouml/model/CollaborationsHelper.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/model/src/org/argouml/model/CollaborationsHelper.java?view=diff&rev=14383&p1=trunk/src/model/src/org/argouml/model/CollaborationsHelper.java&p2=trunk/src/model/src/org/argouml/model/CollaborationsHelper.java&r1=14382&r2=14383
==============================================================================
--- trunk/src/model/src/org/argouml/model/ModelManagementHelper.java (original)
+++ trunk/src/model/src/org/argouml/model/ModelManagementHelper.java 2008-04-18 20:34:35-0700
@@ -50,7 +50,8 @@
String ACCESS_STEREOTYPE = "access";
/**
- * Returns all subsystems found in this namespace and in its children.
+ * Returns all subsystems found in this namespace and in its containing
+ * namespaces.
*
* @param ns is the namespace
* @return Collection
@@ -58,7 +59,8 @@
Collection getAllSubSystems(Object ns);
/**
- * Returns all namespaces found in this namespace and in its children
+ * Returns all namespaces found in this namespace and in its containing
+ * namespaces.
*
* @param ns namespace to process
* @return Collection of all namespaces found
@@ -76,26 +78,26 @@
Collection getAllModelElementsOfKindWithModel(Object model, Object type);
/**
- * Returns all modelelements found in this namespace and its children
- * that are of some class kind.<p>
+ * Returns all modelelements found in this namespace and its containing
+ * namespaces that are of some class kind.<p>
*
- * @param nsa is the namespace
+ * @param namespace is the namespace
* @param type is the class kind
* @return Collection
*/
- Collection getAllModelElementsOfKind(Object nsa, Object type);
+ Collection getAllModelElementsOfKind(Object namespace, Object type);
/**
* helper method for {@link #getAllModelElementsOfKind(Object, Object)}.
*
- * @param nsa
+ * @param namespace
* namespace.
* @param kind
* name of class to find (without implementation-specific
* additions)
* @return a Collection.
*/
- Collection getAllModelElementsOfKind(Object nsa, String kind);
+ Collection getAllModelElementsOfKind(Object namespace, String kind);
/**
* Returns all surrounding namespaces of some namespace ns. See section
@@ -123,8 +125,9 @@
Collection getAllPossibleImports(Object pack);
/**
- * Get the modelelement with the given path, starting at the root of repository.
- *
+ * Get the modelelement with the given path, starting at the root of
+ * repository.
+ *
* @param path the given path
* @return the modelelement looked for, or null if not found
*/
@@ -132,10 +135,10 @@
/**
* Get the modelelement a given path below a given root-namespace.
- *
+ *
* @param path the given path
- * @param theRootNamespace the given namespace to start from. If null, start
- * from the root (equivalent to {@link #getElement(List)}.
+ * @param theRootNamespace the given namespace to start from. If null, start
+ * from the root (equivalent to {@link #getElement(List)}.
* @return the modelelement looked for, or null if not found
*/
Object getElement(List<String> path, Object theRootNamespace);
@@ -260,7 +263,7 @@
/**
* Checks if a child for some ownership relationship (as in a
- * namespace A is owned by a namespace B) is allready in the
+ * namespace A is owned by a namespace B) is already in the
* ownerhship relation.
*
* @param parent The current leaf for the ownership relation
@@ -409,7 +412,7 @@
* self.contents.name->include (e.name) ))
* </pre>
*
- * @param namespace the ns to get the contents from
+ * @param namespace the namespace to get the contents from
* @return a collection of modelelements
*/
Collection getAllContents(Object namespace);
lmpx.com only provides a reader for public news (NNTP) servers. It is not
affiliated with the servers or forums shown here and is not responsible for
the content of articles, which is written by their respective authors.
--- trunk/src/model/src/org/argouml/model/CollaborationsHelper.java (original)
+++ trunk/src/model/src/org/argouml/model/CollaborationsHelper.java 2008-04-18 20:34:35-0700
@@ -36,40 +36,40 @@
* Returns all classifierroles found in this namespace and in its children.
*
* @return Collection collection of all classifierroles
- * @param ns the namespace
+ * @param namespace the namespace
*/
- Collection getAllClassifierRoles(Object ns);
+ Collection getAllClassifierRoles(Object namespace);
/**
* Returns all associations the bases of the classifierrole has,
* thereby forming the set of associationroles the classifierrole
* can use. UML Spec 1.3 section 2.10.3.3.
*
- * @param role the classifierrole
+ * @param classifierRole the classifierrole
* @return Collection the set of associationroles the classifierrole
* can use
*/
- Collection getAllPossibleAssociationRoles(Object role);
+ Collection getAllPossibleAssociationRoles(Object classifierRole);
/**
* Returns all classifierroles associated via associationroles to some
* classifierrole role.
*
- * @param role the classifierrole
+ * @param classifierRole the classifierrole
* @return Collection all classifierroles associated via associationroles
* to the given classifierrole role
*/
- Collection getClassifierRoles(Object role);
+ Collection getClassifierRoles(Object classifierRole);
/**
* Returns the first found associationrole between two
* classifierroles.<p>
*
* @param afrom the first classifierrole
* @param ato the second classifierrole
* @return MAssociationRole the association between them, or null if none
*/
- Object getAssociationRole(Object afrom, Object ato);
+ Object getAssociationRole(Object fromRole, Object toRole);
/**
* Returns all possible activators for some message mes. The
@@ -77,10 +77,10 @@
* the given message that are not part of the predecessors of the
* message and that are not equal to the given message.<p>
*
- * @param ames the message
+ * @param message the message
* @return Collection all possible activators for the given message
*/
- Collection getAllPossibleActivators(Object ames);
+ Collection getAllPossibleActivators(Object message);
/**
* Returns true if the given message has the message activator
@@ -108,10 +108,10 @@
* messages (defined by the predecessor) has a different
* activator.<p>
*
- * @param ames the given message
- * @param anactivator the given activator or null.
+ * @param message the given message
+ * @param activator the given activator or null.
*/
- void setActivator(Object ames, Object anactivator);
+ void setActivator(Object message, Object activator);
/**
* Returns all possible predecessors for some message, taking into account
@@ -129,19 +129,19 @@
* according to the wellformednessrules of section 2.10.3 of the UML 1.3
* spec.
*
* @param arole the given classifierrole
* @param abase the base to be added
*/
- void addBase(Object arole, Object abase);
+ void addBase(Object classifierRole, Object baseClassifier);
/**
* Sets the bases of the given classifierrole to the given
* collection bases.<p>
*
- * @param role the given classifierrole
+ * @param classifierRole the given classifierrole
* @param bases the given collection of bases
*/
- void setBases(Object role, Collection bases);
+ void setBases(Object classifierRole, Collection bases);
/**
* Returns all available features for a given classifierrole as
@@ -149,10 +149,10 @@
* the standard getAvailableFeatures method on ClassifierRole
* since this is derived information.<p>
*
- * @param arole the given classifierrole
+ * @param classifierRole the given classifierrole
* @return Collection all available features
*/
- Collection allAvailableFeatures(Object arole);
+ Collection allAvailableFeatures(Object classifierRole);
/**
* Returns all available contents for a given classifierrole as
@@ -160,10 +160,10 @@
* the standard getAvailableContents method on ClassifierRole
* since this is derived information.
*
- * @param arole the given classifierrole
+ * @param classifierRole the given classifierrole
* @return Collection all available contents
*/
- Collection allAvailableContents(Object arole);
+ Collection allAvailableContents(Object classifierRole);
/**
* Returns all possible bases for the given element
@@ -188,10 +188,10 @@
* To set the base(s) of a ClassifierRole use
* {@link #setBases(Object, Collection)}.
*
* @param arole The given role.
* @param abase The base to set (or <code>null</code> to clear).
*/
- void setBase(Object arole, Object abase);
+ void setBase(Object classifierRole, Object baseClassifier);
/**
* Returns true if a collaboration may be added to the given context. To
@@ -206,10 +206,10 @@
/**
* This method removes a classifier from a classifier role.
*
* @param handle is the classifier role
* @param c is the classifier
*/
- void removeBase(Object handle, Object c);
+ void removeBase(Object classifierRole, Object baseClassifier);
/**
* Remove a constraining element.
@@ -232,9 +232,9 @@
* Removes a successor message.
*
* @param handle the Message that needs to loose a successor
- * @param mess the Message that is removed
+ * @param message the Message that is removed
*/
- void removeSuccessor(Object handle, Object mess);
+ void removeSuccessor(Object handle, Object message);
/**
* Removes a predecessor message.
@@ -264,17 +264,17 @@
* Add a message to an interaction or association role.
*
* @param handle The interaction or association role.
- * @param elem The message.
+ * @param message The message.
*/
- void addMessage(Object handle, Object elem);
+ void addMessage(Object handle, Object message);
/**
* Add Message to a predecessor Message.
*
- * @param handle predecessor Message
- * @param mess Message to be added
+ * @param predecessor predecessor Message
+ * @param message Message to be added
*/
- void addSuccessor(Object handle, Object mess);
+ void addSuccessor(Object predecessor, Object message);
/**
* Adds a predecessor to a message.
Modified: trunk/src/model/src/org/argouml/model/ModelManagementHelper.java
@@ -36,40 +36,40 @@
* classifierroles.<p>
*
- * @param afrom the first classifierrole
- * @param ato the second classifierrole
+ * @param fromRole the first classifierrole
+ * @param toRole the second classifierrole
* @return MAssociationRole the association between them, or null if none
*/
@@ -129,19 +129,19 @@
* spec.
*
- * @param arole the given classifierrole
- * @param abase the base to be added
+ * @param classifierRole the given classifierrole
+ * @param baseClassifier the base to be added
*/
@@ -188,10 +188,10 @@
* {@link #setBases(Object, Collection)}.
*
- * @param arole The given role.
- * @param abase The base to set (or <code>null</code> to clear).
+ * @param classifierRole The given role.
+ * @param baseClassifier The base to set (or <code>null</code> to clear).
*/
@@ -206,10 +206,10 @@
* This method removes a classifier from a classifier role.
*
- * @param handle is the classifier role
- * @param c is the classifier
+ * @param classifierRole is the classifier role
+ * @param baseClassifier is the classifier
*/
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/model/src/org/argouml/model/ModelManagementHelper.java?view=diff&rev=14383&p1=trunk/src/model/src/org/argouml/model/ModelManagementHelper.java&p2=trunk/src/model/src/org/argouml/model/ModelManagementHelper.java&r1=14382&r2=14383
==============================================================================